@@ -28,6 +28,16 @@
 #  define pclose(p) _pclose(p)
 #endif
 
+
+#ifdef NO_ISFINITE
+#  if defined _WIN32 && defined _MSC_VER
+#    define isfinite(x)  (!_isnan(x) && _finite(x))
+#  else
+#    define isfinite(x) ( -DBL_MAX <= (x) && (x) <= DBL_MAX )
+#  endif
+#endif
+
+
 #ifdef STRINGS_H
 #  include <strings.h>
 #else
@@ -81,6 +91,7 @@ double strtod();
 #define E_BADFILE 17
 #define E_MEMORY 18
 #define E_BADNUM 19
+#define E_UNITEND 20 
 
 #define WHITE " \t\n"
 
@@ -110,6 +121,7 @@ struct functype {
   char *param;
   char *def;
   char *dimen;
+  double *domain_min, *domain_max;
 };
 
 struct pair {
